==> create-gooddata-react-app-0.1.28-0.tgz: src/routes/Home.js <==
import React, { useState } from "react";
import { Container, Row, Col } from "react-grid-system";
import { Model } from "@gooddata/react-components";
import { Link } from "react-router-dom";

import C from "../constants";
import Page from "../components/Page";
import YearSelect from "../components/YearSelect";
import TrendWidget from "../components/visualizations/TrendWidget/TrendWidget";
import MeasureByAttributeChangeWidget from "../components/visualizations/MeasureByAttributeChangeWidget/MeasureByAttributeChangeWidget";
import VisualizationBuilderWidget from "../components/visualizations/VisualizationBuilderWidget/VisualizationBuilderWidget";
import { visTypes } from "../components/visualizations/VisualizationBuilderWidget/visTypes";

import sharedStyles from "../shared.module.scss";

const Home = () => {
    const [selectedYear, setSelectedYear] = useState(2017);

    const dateFilters = [
        Model.absoluteDateFilter(C.dateDataset, `${selectedYear}-01-01`, `${selectedYear}-12-31`),
    ];

    return (
        <Page>
            <div className={sharedStyles.Header}>
                <Container fluid xs sm md lg>
                    <Row>
                        <Col className={sharedStyles.Column}>
                            <h2 className={sharedStyles.Title}>Widgets</h2>
                            <YearSelect value={selectedYear} onChange={setSelectedYear} />
                        </Col>
                    </Row>
                </Container>
            </div>
            <Container fluid xs sm md lg>
                <Row>
                    <Col>
                        <TrendWidget
                            filters={dateFilters}
                            headline="Measure trends"
                            initialSelectedMeasuresIdentifiers={[
                                C.measures.grossProfit,
                                C.measures.totalSales,
                            ]}
                        />
                    </Col>
                </Row>
                <Row>
                    <Col>
                        <MeasureByAttributeChangeWidget
                            filters={dateFilters}
                            attributeDisplayFormIdentifier={C.attributeDisplayForms.locationName}
                            measureIdentifier={C.measures.totalSales}
                            isAttributeDisplayFormFixed={false}
                            isMeasureFixed={false}
                            headline="Locations"
                        />
                    </Col>
                </Row>
                <Row>
                    <Col>
                        <VisualizationBuilderWidget
                            headline="Visualization"
                            initialVisType={{
                                ...visTypes[0],
                                buckets: [
                                    {
                                        ...visTypes[0].buckets[0],
                                        items: [Model.measure(C.measures.totalSales)],
                                    },
                                    {
                                        ...visTypes[0].buckets[1],
                                        items: [Model.attribute(C.attributeDisplayForms.locationState)],
                                    },
                                    visTypes[0].buckets[2],
                                ],
                            }}
                            visualizationProps={{
                                filters: dateFilters,
                            }}
                        />
                    </Col>
                </Row>
                <Row>
                    <Col>
                        <div className={sharedStyles.Widget}>
                            <h2 className={sharedStyles.Headline}>Check out</h2>
                            <p>
                                <Link to="/catalogue" className={sharedStyles.Link}>
                                    Catalogue
                                </Link>{" "}
                                that lists identifiers loaded from the current project for Attributes,
                                Attribute Display Forms, Measures and Date Data Sets.
                            </p>
                            <p>
                                <Link to="/editable-visualization" className={sharedStyles.Link}>
                                    Editable Visualization Widget
                                </Link>{" "}
                                that lets you edit a saved Visualization with embedded Analytical Designer.
                            </p>
                            <p>
                                <Link to="/drill-to-modal" className={sharedStyles.Link}>
                                    Drill to Modal Widget
                                </Link>{" "}
                                that when you click a column in a visualization it displays a modal with a
                                visualization filtered by the column that you clicked and sliced by an
                                additional attribute.
                            </p>
                            <p>
                                <Link to="/parametric-dashboard" className={sharedStyles.Link}>
                                    Parametric dashboard
                                </Link>{" "}
                                that demonstrates how to create dashboards examining the same set of measures
                                and attributes using multiple visualizations that can be parametrized and
                                pre-configured.
                            </p>
                        </div>
                    </Col>
                </Row>
            </Container>
        </Page>
    );
};

export default Home;

==> create-gooddata-react-app-0.1.31-0.tgz: src/routes/Home.js <==
import React from "react";
import { Container, Row, Col } from "react-grid-system";
import { Model } from "@gooddata/react-components";
import { Link } from "react-router-dom";

import C from "../constants";
import Page from "../components/Page";
import useYearFilter from "../hooks/useYearFilter";
import LoadableYearSelect from "../components/LoadableYearSelect";
import TrendWidget from "../components/visualizations/TrendWidget/TrendWidget";
import MeasureByAttributeChangeWidget from "../components/visualizations/MeasureByAttributeChangeWidget/MeasureByAttributeChangeWidget";
import VisualizationBuilderWidget from "../components/visualizations/VisualizationBuilderWidget/VisualizationBuilderWidget";
import { visTypes } from "../components/visualizations/VisualizationBuilderWidget/visTypes";

import sharedStyles from "../shared.module.scss";

const Home = () => {
    const [selectedYear, selectedYearFilter, setSelectedYear] = useYearFilter();

    const dateFilters = [selectedYearFilter];

    return (
        <Page>
            <div className={sharedStyles.Header}>
                <Container fluid xs sm md lg>
                    <Row>
                        <Col className={sharedStyles.Column}>
                            <h2 className={sharedStyles.Title}>Widgets</h2>
                            <LoadableYearSelect
                                selectedYear={selectedYear}
                                setSelectedYear={setSelectedYear}
                            />
                        </Col>
                    </Row>
                </Container>
            </div>
            <Container fluid xs sm md lg>
                <Row>
                    <Col>
                        <TrendWidget
                            filters={dateFilters}
                            headline="Measure trends"
                            initialSelectedMeasuresIdentifiers={[
                                C.measures.grossProfit,
                                C.measures.totalSales,
                            ]}
                        />
                    </Col>
                </Row>
                <Row>
                    <Col>
                        <MeasureByAttributeChangeWidget
                            filters={dateFilters}
                            attributeDisplayFormIdentifier={C.attributeDisplayForms.locationName}
                            measureIdentifier={C.measures.totalSales}
                            isAttributeDisplayFormFixed={false}
                            isMeasureFixed={false}
                            headline="Measure difference"
                        />
                    </Col>
                </Row>
                <Row>
                    <Col>
                        <VisualizationBuilderWidget
                            headline="Visualization"
                            initialVisType={{
                                ...visTypes[0],
                                buckets: [
                                    {
                                        ...visTypes[0].buckets[0],
                                        items: [Model.measure(C.measures.totalSales)],
                                    },
                                    {
                                        ...visTypes[0].buckets[1],
                                        items: [Model.attribute(C.attributeDisplayForms.locationState)],
                                    },
                                    visTypes[0].buckets[2],
                                ],
                            }}
                            visualizationProps={{
                                filters: dateFilters,
                            }}
                        />
                    </Col>
                </Row>
                <Row>
                    <Col>
                        <div className={sharedStyles.Widget}>
                            <h2 className={sharedStyles.Headline}>Check out</h2>
                            <p>
                                <Link to="/catalogue" className={sharedStyles.Link}>
                                    Catalogue
                                </Link>{" "}
                                that lists identifiers loaded from the current project for Attributes,
                                Attribute Display Forms, Measures and Date Data Sets.
                            </p>
                            <p>
                                <Link to="/editable-visualization" className={sharedStyles.Link}>
                                    Editable Visualization Widget
                                </Link>{" "}
                                that lets you edit a saved Visualization with embedded Analytical Designer.
                            </p>
                            <p>
                                <Link to="/drill-to-modal" className={sharedStyles.Link}>
                                    Drill to Modal Widget
                                </Link>{" "}
                                that when you click a column in a visualization it displays a modal with a
                                visualization filtered by the column that you clicked and sliced by an
                                additional attribute.
                            </p>
                            <p>
                                <Link to="/parametric-dashboard" className={sharedStyles.Link}>
                                    Parametric dashboard
                                </Link>{" "}
                                that demonstrates how to create dashboards examining the same set of measures
                                and attributes using multiple visualizations that can be parametrized and
                                pre-configured.
                            </p>
                        </div>
                    </Col>
                </Row>
            </Container>
        </Page>
    );
};

export default Home;
